diff --git a/bob/bio/base/preprocessor/Preprocessor.py b/bob/bio/base/preprocessor/Preprocessor.py
index 3534cdde33f0ff47015d191514fad04a45fc1f01..a5b24e28be6e5164e7c8882107ef18efa2f4e033 100644
--- a/bob/bio/base/preprocessor/Preprocessor.py
+++ b/bob/bio/base/preprocessor/Preprocessor.py
@@ -4,7 +4,7 @@
 # @date: Tue Oct  2 12:12:39 CEST 2012
 
 import bob.io.base
-import bob.db.base
+import bob.bio.db
 
 import os
 
@@ -27,11 +27,11 @@ class Preprocessor:
     A list of keyword arguments to be written in the :py:meth:`__str__` function.
   """
 
-  def __init__(self, writes_data = True, load_function = bob.db.base.File.load, **kwargs):
+  def __init__(self, writes_data = True, read_original_data = bob.bio.db.BioFile.load, **kwargs):
     # Each class needs to have a constructor taking
     # all the parameters that are required for the preprocessing as arguments
     self.writes_data = writes_data
-    self.read_original_data = load_function
+    self.read_original_data = read_original_data
     self._kwargs = kwargs
     pass
diff --git a/bob/bio/base/preprocessor/Filename.py b/bob/bio/base/preprocessor/Filename.py
index a78af095cee1ca411107283dc657d62ab0c88088..2b6c6d0475506bf67f19192b1ea46671442eb3a6 100644
--- a/bob/bio/base/preprocessor/Filename.py
+++ b/bob/bio/base/preprocessor/Filename.py
@@ -14,8 +14,8 @@ class Filename (Preprocessor):
   """
 
   def __init__(self):
-    # call base class constructor, using a custom ``load_function`` that does nothing and always returns None
-    Preprocessor.__init__(self, writes_data=False, load_function = lambda x,y,z: None)
+    # call base class constructor, using a custom ``read_original_data`` that does nothing and always returns None
+    Preprocessor.__init__(self, writes_data=False, read_original_data = lambda x,y,z: None)
 
 
   # The call function (i.e. the operator() in C++ terms)